
import java.io.*;
import java.net.*;
import java.awt.*;
import java.awt.event.*;
import java.awt.image.*;
import javax.imageio.*;
import javax.swing.*;
import javax.swing.event.*;

class SeeThroughComponent extends Component {

    private BufferedImage bi;
    float[] scales = { 1f, 1f, 1f, 0.5f };
    float[] offsets = new float[4];
    RescaleOp rop;
    
    public SeeThroughComponent(URL imageSrc) {
        try {
            BufferedImage img = ImageIO.read(imageSrc);
            int w = img.getWidth(null);
            int h = img.getHeight(null);
            bi = new BufferedImage(w, h, BufferedImage.TYPE_INT_ARGB);
            Graphics g = bi.getGraphics();
            g.drawImage(img, 0, 0, null);

        } catch (IOException e) {
            System.out.println("Image could not be read");
//            System.exit(1);
        }
        setOpacity(0.5f);
    }

    public Dimension getPreferredSize() {
        return new Dimension(bi.getWidth(null), bi.getHeight(null));
    }

    public void setOpacity(float opacity) {
        scales[3] = opacity;
        rop = new RescaleOp(scales, offsets, null);
    }

    public void paint(Graphics g) {
        Graphics2D g2d = (Graphics2D)g;
        g2d.setColor(Color.white);
        g2d.fillRect(0,0, getWidth(), getHeight());
        g2d.setColor(Color.black);
        g2d.setFont(new Font("Dialog", Font.BOLD, 24));
        g2d.drawString("Java 2D is great!", 10, 80);
        g2d.drawImage(bi, rop, 0, 0);
    }
}

public class SeeThroughImageApp extends JPanel {

    static String imageFileName = "duke_skateboard.jpg";
    private URL imageSrc;
    SeeThroughComponent st;
    JSlider opacitySlider;

    public SeeThroughImageApp (URL imageSrc) {
        this.imageSrc = imageSrc;
    }

    public SeeThroughImageApp() {
        imageSrc = getClass().getResource(imageFileName);
     }
     
    public void buildUI() {
        st = new SeeThroughComponent(imageSrc);
        opacitySlider = new JSlider(0, 100);
        opacitySlider.addChangeListener(new ChangeListener() {
                public void stateChanged(ChangeEvent e) {
                    JSlider slider = (JSlider)e.getSource();
                    st.setOpacity(slider.getValue()/100f);
                    st.repaint();
                };
            });
    }

    public static void main(String s[]) {
        JFrame f = new JFrame("See Through Image");
  	f.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        SeeThroughImageApp sta = new SeeThroughImageApp();
        sta.buildUI();
        f.add(sta.st);
	f.add(sta.opacitySlider,BorderLayout.SOUTH);
        f.pack();
        f.setVisible(true);
    }
}
